=======
circuit
=======

Minimal pure Python library for building and working with circuit graphs/expressions.

Package Installation and Usage
------------------------------
The package is available on PyPI::

    python -m pip install circuit

The library can be imported in the usual way::

    import circuit
    from circuit import circuit